#!/bin/bash
# 
# pTeX に各言語のハイフン定義ファイルを読み込ませ，
# Babel マクロパッケージをちゃんと使えるようにします．
#
PTEXLIVE_VER=`ls  ../ptexlive-*.tar.gz|sed "s/.*ptexlive-//;s/.tar.gz//"`
pushd ../ptexlive-$PTEXLIVE_VER
. common.sh
popd

# 
test -f $TEXMF/ptex/platex/config/hyphen.cfg && \
     mv $TEXMF/ptex/platex/config/hyphen.cfg \
        $TEXMF/ptex/platex/config/hyphen.cfg.ptex

LOADHYPH_SED="s/\\\\ifx\\\\secondarg\\\\empty/\\\\ifx\\\\false/"

# usage: forcenoutf8 $TEXMF path name
# loadhyph-*.tex use greek characters to detect whether the engine is
# Unicode-aware. So this detection fails in pTeX and its derivatives.
#   (greek characters are present in JIS X 0208)
# This forcenoutf8 procedure disables this detection.
forcenoutf8() {
    echo "[rewriting]     $1/$2/$3"
    test -d "$1/p$2" || $MKDIR "$1/p$2"
    perl -p -e $LOADHYPH_SED \
	< "$1-dist/$2/$3" > "$1/p$2/$3" || exit 1
}

### (1) update detection
forcenoutf8 $TEXMF tex/generic/dehyph-exptl dehypht-x-2009-06-19.tex
forcenoutf8 $TEXMF tex/generic/dehyph-exptl dehyphn-x-2009-06-19.tex

pushd $TEXMF-dist/tex/generic/hyph-utf8/loadhyph
for x in loadhyph-*.tex; do
  (cd ../../../ ; forcenoutf8 $TEXMF tex/generic/hyph-utf8/loadhyph $x)
done
popd

### (2) change encod ing 
pushd $TEXMF-dist/tex/generic/hyph-utf8/patterns
for x in *.tex; do
  (cd ../../../ ; eightbit2hex $TEXMF tex/generic/hyph-utf8/patterns $x)
done
popd
pushd $TEXMF-dist/tex/generic/hyph-utf8/special
for x in *.tex; do
  (cd ../../../ ; eightbit2hex $TEXMF tex/generic/hyph-utf8/special $x)
done
popd

### Following lines are from 6babel.sh of ptexlive-20100322
### (3) change encoding (to coexist with Japanese EUC, SJIS)
## ukrainian as OT2 encoding
perlprint 's/^(ukrainian\s+ukrhyph.tex)/%! \1/g;
           s/^%! (ukrainian\s+ukrhyph.ot2)/\1/g' \
       $TEXMF/tex/generic/config/language.dat
distcp $TEXMF tex/generic/ukrhyph ukrhyph.tex
perlprint 's/(\\patterns\{ c8h d8j k8h l8j n8j s8h s8h8c8h t8s x8q y8a y8u z8h \})/%\1/g' \
       $TEXMF/tex/generic/ukrhyph/ukrhyph.tex

## russian as OT2 encoding
distcp $TEXMF tex/generic/ruhyphen ruhyphen.tex
perlprint 's/^(\\def\\Encoding\{t2a\})/%\1/g;
           s/%(\\def\\Encoding\{ot2\})/\1/g' \
       $TEXMF/tex/generic/ruhyphen/ruhyphen.tex
distcp $TEXMF tex/generic/ruhyphen koi2ot2.tex
perlprint 's/^%(\\patterns)/\1/g' \
       $TEXMF/tex/generic/ruhyphen/koi2ot2.tex
distcp $TEXMF tex/generic/ruhyphen ruhyphal.tex
perlprint 's/^(2\xcb1\xc82)$/%\1/g;
           s/^(\xd31\xc82)$/%\1/g;
           s/^(4\xd41\xd32)$/%\1/g;
           s/^(2\xdb1\xde)$/%\1/g;
           s/^(\xd9\xd52)$/%\1/g' \
       $TEXMF/tex/generic/ruhyphen/ruhyphal.tex

### (4) convert 8bit character into ^^?? form
eightbit2hex $TEXMF tex/generic/ukrhyph  ukrhypmp.tex
eightbit2hex $TEXMF tex/generic/ruhyphen ruhyphen.tex
eightbit2hex $TEXMF tex/generic/ruhyphen catkoi.tex
eightbit2hex $TEXMF tex/generic/ruhyphen koi2ot2.tex
eightbit2hex $TEXMF tex/generic/ruhyphen ruhyphal.tex
eightbit2hex $TEXMF tex/generic/ruhyphen cyryoal.tex

## (5) update fmt
$MKTEXLSR || exit
fmtutil-sys --byfmt latex  || exit
fmtutil-sys --byfmt platex || exit
fmtutil-sys --byfmt eplatex || exit
#fmtutil-sys --byfmt uplatex || exit
#fmtutil-sys --byfmt euplatex || exit

### (6) japanese style
pushd ../ptexlive-$PTEXLIVE_VER
tarx babel/japanese.zip $TEXMF/ptex/generic/babel/japanese
(cd $TEXMF/ptex/generic/babel/japanese || exit
platex --kanji=jis japanese.ins || exit
$MKDIR $TEXMF/doc/japanese || exit
$MV README sample.tex sample.pdf $TEXMF/doc/japanese || exit
$RM japanese.log || exit
)
popd
$MKTEXLSR || exit
